#!/usr/bin/env python
# *********************************************************************
# * Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)         *
# *                                                                   *
# * For the license terms see the file LICENCE, distributed           *
# * along with this software.                                         *
# *********************************************************************
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


import os

from __logging__ import logger, abort


class E3TextInputFile:
    
    """ Basic data file descriptor for a generic input text file.
    """

    FILE_EXTENSION = '.out'

    def __init__(self, filePath):
        """ Constructor.
        """
        if not os.path.exists(filePath):
            abort('Could not find input file %s.' % filePath)
        if not filePath.endswith(self.FILE_EXTENSION):
            abort('Input file doesn\'t have the right extension (%s).' %\
                      self.FILE_EXTENSION)
        logger.info('Opening input file %s...' % filePath)
        self.FilePath = filePath
        self.FileObject = file(self.FilePath)
        self.Header = self.FileObject.next().strip('\r\n')
        logger.info('Input file open and ready to be read.')

    def isCernNtuple(self):
        """ Return true if the file header looks like that of a cern ntuple.
        """
        return self.Header == '  run_number,event_number,secs_since_1.1.2007,nanosec,microseconds_since_start_of_runtrack: unit_vector_x,unit_vector_y,unit_vector_z,chi_squared,time of flight[ns],track length[cm]'

    def isTextNtuple(self):
        """ Return true if the file header looks like that of a text ntuple.
        """
        return self.Header.startswith('E3TextNtuple:')

    def __iter__(self):
        """ This is necessary to implement the iterator behavior.
        """
        return self

    def next(self):
        """ And this is the main iteration function.
        """
        return self.FileObject.next().strip('\n\r')

    def close(self):
        """ Close the underlying file object.
        """
        self.FileObject.close()
        logger.info('Input file %s closed.' % self.FilePath)



if __name__ == '__main__':
    from __eee__ import DATA_FOLDER
    filePath = os.path.join(DATA_FOLDER, 'sample_cerntuple.out')
    inputFile = E3TextInputFile(filePath)
    for i in range(10):
        print(inputFile.next())
    inputFile.close()
