/*
  Copyright (C) 2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef E3BitMask_H
#define E3BitMask_H


#include <iostream>
#include <bitset>


/*! \class E3BitMask
  \brief Generic 32-bit (or whatever an unsigned int implies in any specific
  platform) bit mask desctiptor.
*/


class E3BitMask
{
 public:
  /// \brief Default constructor.
  E3BitMask();
  
  /// \brief Destructor.
  ~E3BitMask() {}
  
  /// \brief Return the plain payload.
  inline unsigned int payload() const { return m_payload; }

  /// \brief Set a specific bit in the bit mask.
  inline void setBit(unsigned int position)
  { m_payload |= (0x1 << position); }

  /// \brief Clear a specific bit in the bit mask.
  inline void clearBit(unsigned int position)
  { m_payload ^= (0x1 << position); }

  /// \brief Test whether a specific bit in the bitmask is set.
  inline bool checkBit(unsigned int position) const
  { return ((m_payload >> position) & 0x1) ; }

  /// \brief Standard output.
  std::ostream& fillStream(std::ostream& os) const;

  /// \brief Standard output.
  friend std::ostream& operator<<(std::ostream& os, const E3BitMask& b)
  { return b.fillStream(os); }

 private:
  /// \brief The underlying int.
  unsigned int m_payload;
};

#endif
