/*
  Copyright (C) 2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


#include "E3CernNtuple.h"


E3CernNtuple::E3CernNtuple() :
  E3TextNtuple("CernTuple")
{}


void E3CernNtuple::writeHeader()
{
  LOG(INFO) << "Writing ntuple header...";
  *this << "  run_number,event_number,secs_since_1.1.2007,nanosec,"
        << "microseconds_since_start_of_runtrack: unit_vector_x,unit_vector_y,"
        << "unit_vector_z,chi_squared,time of flight[ns],track length[cm]"
        << m_eol << std::fixed;
}

void E3CernNtuple::addColumns()
{}


void E3CernNtuple::writeRow(const E3Event &event)
{
  write(event.runId(), 6);
  write(event.eventId(), 11);
  write(event.seconds(), 11);
  write(event.nanoseconds(), 11);
  write(long(event.timeSinceStartRun()*1e6), 13);
  if (event.numTracks()) {
    E3Track bestTrack = event.bestTrack();
    write(bestTrack.xdir(), 10, 5);
    write(bestTrack.ydir(), 10, 5);
    write(bestTrack.zdir(), 10, 5);
    write(std::min(100., bestTrack.chisquare()), 9, 4);
    write(bestTrack.timeOfFlight(), 11, 3);
    write(bestTrack.length(), 11, 2);
  } else {
    write(-1, 10);
    write(-1, 10);
    write(-1, 10);
    write(-1, 8);
    write(-1, 11);
    write(-1, 11);
  }
  endline();
}
