/*
  Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef E3Coincidence_H
#define E3Coincidence_H

#include <utility>

#include "E3BaseEvent.h"


/*! \class E3Coincidence
  \brief Class describing a temporal coincidence between two events.
*/

class E3Coincidence
{
 public:
  /// \brief Deafult constructor.
  E3Coincidence(E3BaseEvent first, E3BaseEvent second);

  /// \brief Destructor.
  ~E3Coincidence() {}

  /// \brief Return the first event in the coincidence.
  E3BaseEvent first() const { return m_eventPair.first; }

  /// \brief Return the second event in the coincidence.
  E3BaseEvent second() const { return m_eventPair.second; }

  /// \brief Return the time difference (in s) between the two events.
  double deltas() const { return delta(first(), second()); }

  /// \brief Return the time difference (in ns) between the two events.
  long deltans() const
  { return (first().timestamp() - second().timestamp()).nanoseconds(); }
 
  /// \brief Standard output.
  std::ostream& fillStream(std::ostream& os) const;

  /// \brief Standard output.
  friend std::ostream& operator<<(std::ostream& os, const E3Coincidence& c)
  { return c.fillStream(os); }

 private:
  /// \brief The underlying pair of events.
  std::pair<E3BaseEvent, E3BaseEvent> m_eventPair;
};

#endif
