/*
  Copyright (C) 2012--2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef E3GpsRecord_H
#define E3GpsRecord_H

#include <iomanip>

#include "E3AncillaryRecord.h"
#include "E3Timestamp.h"
#include "E3.h"


/*! \class E3GpsRecord
  \brief 
*/

class E3GpsRecord : public E3AncillaryRecord
{
 public:
  /// \brief Default constructor.
  E3GpsRecord(E3::UnixTime_t unixTime, type_eee_gps_record data);

  /// \brief Destructor.
  ~E3GpsRecord() {}

  /// \brief
  inline const char* gpgga() const
  { return m_gpgga; }

  /// \brief Recommended minimum specific GPS/Transit data.
  inline const char* gprmc() const
  { return m_gprmc; }

  /// \brief 
  inline int quality() const
  { return m_quality; }

  /// \brief 
  inline float utcDate() const
  { return m_utcDate; }

  /// \brief 
  inline float utcTime() const
  { return m_utcTime; }

  /// \brief 
  inline float latitude() const
  { return m_latitude; }
  
  /// \brief 
  inline float longitude() const
  { return m_longitude; }

  /// \brief 
  inline char latHem() const
  { return m_latHem; }

  /// \brief 
  inline char lonHem() const
  { return m_lonHem; }

  /// \brief
  inline E3Timestamp timestamp() const
  { return m_timestamp; }

  /// \brief Standard output.
  std::ostream& fillStream(std::ostream& os) const;

  /// \brief Standard output.
  friend std::ostream& operator<<(std::ostream& os, const E3GpsRecord& r)
  { return r.fillStream(os); }

 private:
  /// \brief Global Positioning System Fix Data.
  char m_gpgga[128];

  /// \brief Recommended minimum specific GPS/Transit data.
  char m_gprmc[128];

  /// \brief 
  int m_quality;

  /// \brief 
  float m_utcDate;

  /// \brief 
  float	m_utcTime;

  /// \brief 
  float m_latitude;
  
  /// \brief 
  float	m_longitude;

  /// \brief 
  char m_latHem;

  /// \brief 
  char m_lonHem;

  /// \brief The timestamp (from January 1, 2007) corresponding to the temporal
  /// part of the record.
  E3Timestamp m_timestamp;
};

#endif
