/*
  Copyright (C) 2012--2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include "E3NinoMap.h"


E3NinoMap::E3NinoMap(E3::NinoMap_t payload) :
  m_payload(payload)
{}


E3::Nino_t E3NinoMap::nino(E3::Board_t board, E3::Tdc_t tdc) const
{
  return (m_payload >> (16*board + 4*tdc)) & 0xf;
}


E3::Plane_t E3NinoMap::plane(E3::Board_t board, E3::Tdc_t tdc) const
{
  E3::Nino_t ninoId = nino(board, tdc);
  if (ninoId < 2) return E3::kTopPlane;
  else if (ninoId < 4) return E3::kMidPlane;
  else if (ninoId < 6) return E3::kBotPlane;
  return E3::kInvalidPlane;
}
 

bool E3NinoMap::side(E3::Board_t board, E3::Tdc_t tdc) const
{
  if (nino(board, tdc) % 2 == 0) return E3::kPosEnd;
  return E3::kNegEnd;
}


std::ostream& E3NinoMap::fillStream(std::ostream& os) const
{
  os << std::hex << std::showbase << m_payload << std::dec << std::noshowbase;
  return os;
}
