/*
  Copyright (C) 2012--2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef E3RunInfo_H
#define E3RunInfo_H

#include <string>

#include "E3NinoMap.h"
#include "E3TriggerMask.h"
#include "E3GpsRecord.h"


class E3RunInfo
{
 public:
  /// \brief Default constructor from all parameters.
  E3RunInfo(E3::Version_t versionNumber, E3::Station_t stationId,
            E3::Run_t runId, std::string runName,
            E3::TriggerMask_t triggerMask, E3NinoMap ninoMap,
            E3GpsRecord startRunGpsRecord);

  /// \brief Destructor.
  ~E3RunInfo() {}

  /// \brief Return the file header version number.
  inline E3::Version_t versionNumber() const
  { return m_versionNumber; }

  /// \brief Return the station Id for the run.
  inline E3::Station_t stationId() const
  { return m_stationId; }

  /// \brief Return the run Id.
  inline E3::Run_t runId() const
  { return m_runId; }

  /// \brief Return the run name.
  inline std::string runName() const
  { return m_runName; }

  /// \brief The trigger mask.
  E3TriggerMask triggerMask() const
  { return m_triggerMask; }

  /// \brief The nino map.
  inline E3NinoMap ninoMap() const
  { return m_ninoMap; }

  /// \brief The GPS record at the start run.
  inline E3GpsRecord startRunGpsRecord() const { return m_startRunGpsRecord; }

  /// \brief Standard output.
  std::ostream& fillStream(std::ostream& os) const;

  /// \brief Standard output.
  friend std::ostream& operator<<(std::ostream& os, const E3RunInfo& r)
  { return r.fillStream(os); }

 private:
  /// \brief The version number of the file header.
  E3::Version_t m_versionNumber;

  /// \brief The station Id for the run.
  E3::Station_t m_stationId;

  /// \brief The run Id.
  E3::Run_t m_runId;

  /// \brief The run name.
  std::string m_runName;

  /// \brief The trigger mask.
  E3TriggerMask m_triggerMask;

  /// \brief The nino map.
  E3NinoMap m_ninoMap;

  /// \brief The GPS record at the start run.
  E3GpsRecord m_startRunGpsRecord;
};

#endif
