/*
  Copyright (C) 2012--2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include "E3StripData.h"


E3StripData::E3StripData(E3::Plane_t plane, E3::Channel_t channel) :
  m_plane(plane),
  m_channel(channel)
{
  clear();
}


void E3StripData::clear()
{
  m_edgeDigiVec[0].clear();
  m_edgeDigiVec[1].clear();
}


void E3StripData::addEdgeDigi(bool side, E3DigiWord digi)
{
  m_edgeDigiVec[side].push_back(digi);
}


std::ostream& E3StripData::fillStream(std::ostream& os) const
{
  os << "Strip data (plane " << m_plane << ", channel " << m_channel << ")..."
     << std::endl;
  E3DigiWordVecIter digi, begin, end;
  os << "  [+ side]: ";
  begin = m_edgeDigiVec[E3::kPosEnd].begin();
  end = m_edgeDigiVec[E3::kPosEnd].end();
  for (digi = begin; digi != end; digi++) {
    os << digi->ps();
    if (digi->isRisingEdge()) os << "[r] ps";
    else if (digi->isFallingEdge()) os << "[f] ps";
    if (digi < end - 1) os << ", ";
  }
  os << std::endl << "  [- side]: ";
  begin = m_edgeDigiVec[E3::kNegEnd].begin();
  end = m_edgeDigiVec[E3::kNegEnd].end();
  for (digi = begin; digi != end; digi++) {
    os << digi->ps();
    if (digi->isRisingEdge()) os << "[r] ps";
    else if (digi->isFallingEdge()) os << "[f] ps";
    if (digi < end - 1) os << ", ";
  }
  return os;
}
