/*
  Copyright (C) 2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


#include "E3SummaryNtuple.h"


E3SummaryNtuple::  E3SummaryNtuple() :
  E3MinimalNtuple("SummaryTuple")
{}


void E3SummaryNtuple::addColumns()
{
  // First add the columns defined in the E3MinimalNtuple class...
  E3MinimalNtuple::addColumns();
  // ...and then the extra goodies.
  addColumn("NumTopHits", 'I');
  addColumn("NumMidHits", 'I');
  addColumn("NumBotHits", 'I');
  addColumn("NumTopClusters", 'I');
  addColumn("NumMidClusters", 'I');
  addColumn("NumBotClusters", 'I');
  addColumn("NumTracks", 'I');
  addColumn("BestTrackXDir", 'D');
  addColumn("BestTrackYDir", 'D');
  addColumn("BestTrackZDir", 'D');
  addColumn("BestTrackTheta", 'D');
  addColumn("BestTrackPhi", 'D');
  addColumn("BestTrackChiSquare", 'D');
  addColumn("BestTrackTimeOfFlight", 'D');
  addColumn("BestTrackLength", 'D');
  addColumn("BestTrackTopX", 'D');
  addColumn("BestTrackTopY", 'D');
  addColumn("BestTrackTopHitTime", 'D');
  addColumn("BestTrackMidX", 'D');
  addColumn("BestTrackMidY", 'D');
  addColumn("BestTrackMidHitTime", 'D');
  addColumn("BestTrackBotX", 'D');
  addColumn("BestTrackBotY", 'D');
  addColumn("BestTrackBotHitTime", 'D');
}


void E3SummaryNtuple::writeRow(const E3Event &event)
{
  // First write the variables defined in the E3MinimalNtuple class...
  E3MinimalNtuple::writeRow(event, false);
  // ...and then the rest of the stuff.
  write(event.numHits(E3::kTopPlane), 5);
  write(event.numHits(E3::kMidPlane), 5);
  write(event.numHits(E3::kBotPlane), 5);
  write(event.numClusters(E3::kTopPlane), 5);
  write(event.numClusters(E3::kMidPlane), 5);
  write(event.numClusters(E3::kBotPlane), 5);
  write(event.numTracks(), 5);
  E3Track bestTrack = event.bestTrack();
  write(bestTrack.xdir(), 10, 5);
  write(bestTrack.ydir(), 10, 5);
  write(bestTrack.zdir(), 10, 5);
  write(bestTrack.theta(), 10, 2);
  write(bestTrack.phi(), 10, 2);
  write(std::min(100., bestTrack.chisquare()), 9, 4);
  write(bestTrack.timeOfFlight(), 11, 3);
  write(bestTrack.length(), 11, 2);
  E3Cluster cluster = bestTrack.cluster(E3::kTopPlane);
  write(cluster.x(), 10, 3);
  write(cluster.y(), 10, 3);
  write(cluster.hitTime(), 10, 3);
  cluster = bestTrack.cluster(E3::kMidPlane);
  write(cluster.x(), 10, 3);
  write(cluster.y(), 10, 3);
  write(cluster.hitTime(), 10, 3);
  cluster = bestTrack.cluster(E3::kBotPlane);
  write(cluster.x(), 10, 3);
  write(cluster.y(), 10, 3);
  write(cluster.hitTime(), 10, 3);
  endline();
}
