/*
  Copyright (C) 2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


#ifndef E3TerminalFormatting_H
#define E3TerminalFormatting_H


#include <iostream>
#include <string>
#include <sstream>

#include "__version__.h"


namespace E3TerminalFormatting {

  /// \brief Print a welcome message with the program version and build date.
  void startmsg();

  /// \brief The default number of characters in a terminal row.
  static const unsigned short int kTerminalWidth = 80;
  
  /// \brief 
  static const unsigned short int kTitlePadding = 1;

  /// \brief The basic character to build horizontal lines.
  static const std::string kHorLineChar = "-";

  /// \brief The eol char.
  static const std::string kEolChar = "\n";

  /// \brief Return an horizontal line with the default terminal width.
  std::string hline(bool eol = false);

  /// \brief Return a formatted title.
  std::string title(std::string text, bool eol = false);

  /// \brief Return a formatted key/value pair.
  template <class T> std::string keyval(std::string key, T value,
					std::string units = "",
					unsigned int width = 25,
					bool eol = true)
    {
      std::stringstream s("");
      s << key;
      for (unsigned int i = 0; i < width - key.size(); i++) {
	s << ".";
      }
      s << ": " << value;
      if (units.size()) s << " " << units;
      if (eol) s << kEolChar;
      return s.str();
    }
}

#endif
