/*
  Copyright (C) 2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


#include "E3TextNtuple.h"


E3TextNtuple::E3TextNtuple(std::string label):
  m_label(label),
  m_separator(" "),
  m_eol("\r\n")
{
  m_columns.clear();
}


StatusCode E3TextNtuple::open(const char* filePath)
{
  LOG(INFO) << "Setting up \"" << m_label << "\" text ntuple...";
  addColumns();
  if (E3TextOutputFile::open(filePath)) return StatusCode::FAILURE;
  writeHeader();
  return StatusCode::SUCCESS;
}


StatusCode E3TextNtuple::open(const std::string filePath)
{
  LOG(INFO) << "Setting up \"" << m_label << "\" text ntuple...";
  addColumns();
  if (E3TextOutputFile::open(filePath)) return StatusCode::FAILURE;
  writeHeader();
  return StatusCode::SUCCESS;
}


void E3TextNtuple::addColumn(std::string name, char type)
{
  LOG(INFO) << "Adding column " << name << " [" << type << "]...";
  m_columns.push_back(std::make_pair(name, type));
}


void E3TextNtuple::writeHeader()
{
  LOG(INFO) << "Writing ntuple header...";
  *this << "E3TextNtuple:" << m_label << m_eol;
  std::vector<std::pair<std::string, char>>::const_iterator col;
  for (col = m_columns.begin(); col != m_columns.end() - 1; col++) {
    *this << (*col).first << "/" << (*col).second << m_separator;
  }
  *this << (*col).first << "/" << (*col).second << m_eol << std::fixed;
}

