/*
  Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include "E3RawDataFile.h"
#include "E3Option.h"
#include "E3OptionParser.h"
#include "E3DigiEvent.h"
#include "E3TerminalFormatting.h"


int main (int argc, char* argv[]) {

  E3TerminalFormatting::startmsg();

  // Setup command-line options.
  std::string intent =
    "Read a binary data (.dat) file and print the content to terminal";
  std::string usage = "e3dumpdigi [options] file.dat";
  E3OptionParser parser(intent, usage);
  parser.addOption<int>("num-events", 'n', 10,
                        "Number of events to be processed");
  parser.addOption<bool>("interactive", 'i',
                         "Run interactively (stop after each event)");
  parser.parse(argc, argv);
  if (parser.numArguments() != 1) {
    parser.parseError("Please provide exactly one input .dat file.");
  }

  // Parse options.
  std::string filePath = parser.getArguments().front();  
  const int numEvents = parser.getOption<int>("num-events");
  bool interactive = parser.getOption<bool>("interactive");

  // Try and open the input file.
  E3RawDataFile inputFile;
  if (inputFile.open(filePath)) exit(1);

  // Read the file header.
  E3RunInfo runInfo = inputFile.parseHeader();

  // Loop through the events.
  for (int i = 1; i <= numEvents; i++) {
    E3DigiEvent event = inputFile.next();
    if (event.unpack(runInfo) == StatusCode::FAILURE) {
      exit(1);
    }
    std::cout << std::endl << event << std::endl;
    if (interactive) {
      std::string input;
      std::cout << "Type ENTER to continue, q + ENTER to quit." << std::endl;
      getline(std::cin, input);
      if (input == "q") break;
    }
  }
  return 0;
}
