/*
  Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include "E3EventList.h"


int main () {
  double startTime = 0;
  double stopTime = 86400;
  double rate1 = 20.;
  double rate2 = 15.;
  double coincidenceRate = 0.01;
  double timeResolution = 50e-9;
  double searchWindow = 1e-6;

  // Start with filling the list of coincidences...
  E3EventList eventListCoinc;
  eventListCoinc.fillRandom(coincidenceRate, startTime, stopTime, 1);
  std::cout << eventListCoinc << std::endl;
  // ...and smear it with the time resolution in two different flavours.
  E3EventList eventListCoinc1 = eventListCoinc.smear(timeResolution, 2);
  eventListCoinc1.setStationId(-1);
  eventListCoinc1.setRunId(1);
  std::cout << eventListCoinc1 << std::endl;
  E3EventList eventListCoinc2 = eventListCoinc.smear(timeResolution, 3);
  eventListCoinc2.setStationId(-2);
  eventListCoinc2.setRunId(1);
  std::cout << eventListCoinc2 << std::endl;
  E3CoincidenceList trueCoincList;
  for (unsigned long i = 0; i < eventListCoinc.numEvents(); i++) {
    trueCoincList.fill(eventListCoinc1.at(i), eventListCoinc2.at(i));
  }
  std::cout << trueCoincList << std::endl;
  trueCoincList.write("../data/true_coincidences.txt");

  // Fill the first list of events.
  E3EventList eventList1;
  eventList1.fillRandom(rate1, startTime, stopTime, 4, -1, 0);
  eventList1.fill(eventListCoinc1);
  eventList1.sort();
  eventList1.align();

  // Fill the second list of events.
  E3EventList eventList2;
  eventList2.fillRandom(rate2, startTime, stopTime, 5, -2, 0);
  eventList2.fill(eventListCoinc2);
  eventList2.sort();
  eventList2.align();
  
  // Finally: search for coincidences!
  E3CoincidenceList recCoincList = match(eventList1, eventList2, searchWindow);
  std::cout << recCoincList << std::endl;
  recCoincList.write("../data/rec_coincidences.txt");

  return 0;
}
